@@ -45,6 +45,7 @@ class Client:
     ) -> None:
         self.api_key = api_key
         self.api_url = clueai.MODELFUN_API_URL
+        self.text_2_image_api_url = clueai.TEXT_TO_IMAGE_URL
         self.num_workers = num_workers
         self.request_dict = request_dict
         if version is None:
@@ -93,6 +94,31 @@ class Client:
                 headers=response.headers)
         return res
 
+    def text2image(
+        self,
+        prompt: str,
+        model_name: str = None,
+        style: str="",
+        out_file_path: str="test.png"
+        ) -> None:
+        url = f"{self.text_2_image_api_url}{prompt}"
+        if style:
+            url = f"{self.text_2_image_api_url}使用{style}风格画{prompt}"
+        
+        headers = {
+            'Api-Key': 'BEARER {}'.format(self.api_key),
+            'Content-Type': 'application/json',
+            'Request-Source': 'python-sdk',
+            'Model-name': model_name
+        }
+        if self.modelfun_version != '':
+            headers['clueai-Version'] = self.modelfun_version
+
+        response = requests.get(url, headers=headers)
+        img = response.content
+        with open(out_file_path, "wb") as f:
+            f.write(img)
+
     def generate(
         self,
         prompt: str,
